@@ -1,7 +1,7 @@
 package App::IODUtils;
 
-our $VERSION = '0.03'; # VERSION
-our $DATE = '2014-08-30'; # DATE
+our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-03-18'; # DATE
 
 use 5.010001;
 
@@ -11,15 +11,53 @@ our %common_args = (
         schema  => ['str*'],
         req     => 1,
         pos     => 0,
-        cmdline_src => 'stdin_or_files',
+        cmdline_src => 'stdin_or_file',
+        tags    => ['common'],
     },
     enable_expr => {
         schema  => 'bool',
         default => 0,
         cmdline_aliases => {e=>{}},
+        tags    => ['common'],
     },
 );
 
+our %inplace_arg = (
+    inplace => {
+        summary => 'Modify file in-place',
+        schema => ['bool', is=>1],
+        description => <<'_',
+
+Note that this can only be done if you specify an actual file and not STDIN.
+Otherwise, an error will be thrown.
+
+_
+    },
+);
+
+sub _check_inplace {
+    my $args = shift;
+    if ($args->{inplace}) {
+        die [412, "To use in-place editing, please supply an actual file"]
+            if @{ $args->{-cmdline_srcfilenames_iod} // []} == 0;
+        die [412, "To use in-place editing, please supply only one file"]
+            if @{ $args->{-cmdline_srcfilenames_iod} // []} > 1;
+    }
+}
+
+sub _return_mod_result {
+    my ($args, $doc) = @_;
+
+    if ($args->{inplace}) {
+        require File::Slurper;
+        File::Slurper::write_text(
+            $args->{-cmdline_srcfilenames_iod}[0], $doc->as_string);
+        [200, "OK"];
+    } else {
+        [200, "OK", $doc->as_string, {'cmdline.skip_format'=>1}];
+    }
+}
+
 1;
 # ABSTRACT: IOD utilities
 
@@ -35,7 +73,7 @@ App::IODUtils - IOD utilities
 
 =head1 VERSION
 
-This document describes version 0.03 of App::IODUtils (from Perl distribution App-IODUtils), released on 2014-08-30.
+This document describes version 0.04 of App::IODUtils (from Perl distribution App-IODUtils), released on 2015-03-18.
 
 =head1 SYNOPSIS
 
@@ -68,7 +106,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
